@@ -5,7 +5,7 @@
 #  ALL RIGHTS RESERVED.
 #
 #  Authors: Vasya Svintsov <v.svintsov@techokert.ru>
-
+import yarl
 from aiohttp import ClientSession, ClientResponse
 from aiohttp.typedefs import StrOrURL
 
@@ -18,7 +18,7 @@ class MonitoredClientSession(ClientSession):
         super().__init__(*args, **kwargs)
 
     async def _request(self, method: str, str_or_url: StrOrURL, **kwargs) -> ClientResponse:
-        labels = {'method': method.upper(), 'url': str_or_url}
+        labels = {'method': method.upper(), 'url': str(yarl.URL(StrOrURL).with_query({}))}
         with self._metrics.track('http_client__requests', labels) as tracker:
             try:
                 response = await super()._request(method, str_or_url, **kwargs)
